@@ -27,7 +27,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <glob.h>
 #include <unistd.h>
 #include "gettext.h"
 #include <curl/curl.h>
@@ -111,15 +110,19 @@ static gint vcal_remove_folder(Folder *folder, FolderItem *item);
 static gboolean vcal_scan_required(Folder *folder, FolderItem *item);
 static void vcal_set_mtime(Folder *folder, FolderItem *item);
 static void vcal_change_flags(Folder *folder, FolderItem *_item, MsgInfo *msginfo, MsgPermFlags newflags);
-static void new_meeting_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void export_cal_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void subscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void check_subs_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void unsubscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void set_view_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item);
+
+static void new_meeting_cb(GtkAction *action, gpointer data);
+static void export_cal_cb(GtkAction *action, gpointer data);
+static void subscribe_cal_cb(GtkAction *action, gpointer data);
+static void check_subs_cb(GtkAction *action, gpointer data);
+static void unsubscribe_cal_cb(GtkAction *action, gpointer data);
+static void rename_cb(GtkAction *action, gpointer data);
+static void set_view_cb(GtkAction *action, GtkRadioAction *current, gpointer data);
+
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item);
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item);
+
 static void update_subscription(const gchar *uri, gboolean verbose);
-static void rename_cb(FolderView *folderview, guint action, GtkWidget *widget);
 static void vcal_folder_set_batch	(Folder		*folder,
 					 FolderItem	*item,
 					 gboolean	 batch);
@@ -154,41 +157,38 @@ struct _VCalFolderItem
 
 static char *vcal_popup_labels[] =
 {
-	N_("/_New meeting..."),
-	N_("/_Export calendar..."),
-	"/---",
-	N_("/_Subscribe to webCal..."),
-	N_("/_Unsubscribe..."),
-	"/---",
-	N_("/_Rename..."),
-	"/---",
-	N_("/U_pdate subscriptions"),
-	"/---",
-	N_("/_List view"),
-	N_("/_Week view"),
-	N_("/_Month view"),
-	"/---",
+	N_("_New meeting..."),
+	N_("_Export calendar..."),
+	N_("_Subscribe to webCal..."),
+	N_("_Unsubscribe..."),
+	N_("_Rename..."),
+	N_("U_pdate subscriptions"),
+	N_("_List view"),
+	N_("_Week view"),
+	N_("_Month view"),
 	NULL
 };
-	
-static GtkItemFactoryEntry vcal_popup_entries[] =
-{
-	{NULL, NULL, new_meeting_cb,	0, NULL},
-	{NULL, NULL, export_cal_cb,	0, NULL},
-	{NULL, NULL, NULL,    	0, "<Separator>"},
-	{NULL, NULL, subscribe_cal_cb,	0, NULL},
-	{NULL, NULL, unsubscribe_cal_cb,	0, NULL},
-	{NULL, NULL, NULL,    	0, "<Separator>"},
-	{NULL, NULL, rename_cb, 0, NULL},
-	{NULL, NULL, NULL,    	0, "<Separator>"},
-	{NULL, NULL, check_subs_cb, 0, NULL},
-	{NULL, NULL, NULL,  	0, "<Separator>"},
-	{NULL, NULL, set_view_cb, 0, "<RadioItem>"},
-	{NULL, NULL, set_view_cb, 1, "/List view"},
-	{NULL, NULL, set_view_cb, 2, "/List view"},
-	{NULL, NULL, NULL,  	0, "<Separator>"}
-};
 
+static GtkActionEntry vcal_popup_entries[] = 
+{
+	{"FolderViewPopup/NewMeeting",		NULL, NULL, NULL, NULL, G_CALLBACK(new_meeting_cb) },
+	{"FolderViewPopup/ExportCal",		NULL, NULL, NULL, NULL, G_CALLBACK(export_cal_cb) },
+
+	{"FolderViewPopup/SubscribeCal",	NULL, NULL, NULL, NULL, G_CALLBACK(subscribe_cal_cb) },
+	{"FolderViewPopup/UnsubscribeCal",	NULL, NULL, NULL, NULL, G_CALLBACK(unsubscribe_cal_cb) },
+
+	{"FolderViewPopup/RenameFolder",	NULL, NULL, NULL, NULL, G_CALLBACK(rename_cb) },
+
+	{"FolderViewPopup/CheckSubs",		NULL, NULL, NULL, NULL, G_CALLBACK(check_subs_cb) },
+
+};			
+
+static GtkRadioActionEntry vcal_popup_radio_entries[] = { /* set_view_cb */
+	{"FolderViewPopup/ListView",		NULL, NULL, NULL, NULL, 0 }, 
+	{"FolderViewPopup/WeekView",		NULL, NULL, NULL, NULL, 1 }, 
+	{"FolderViewPopup/MonthView",		NULL, NULL, NULL, NULL, 2 }, 
+};
+		
 static IcalFeedData *icalfeeddata_new(icalcomponent *evt, gchar *str)
 {
 	IcalFeedData *data = g_new0(IcalFeedData, 1);
@@ -214,21 +214,27 @@ static void slist_free_icalfeeddata(GSList *list)
 
 static void vcal_fill_popup_menu_labels(void)
 {
-	gint i;
-
-	for( i = 0; vcal_popup_labels[i] != NULL; i++ ) {
-		(vcal_popup_entries[i]).path = _(vcal_popup_labels[i]);
-		if (!strcmp2(vcal_popup_entries[i].item_type, "/List view")) {
-			vcal_popup_entries[i].item_type = _(vcal_popup_entries[i].item_type);
-		}
-	}
+	vcal_popup_entries[0].label = _(vcal_popup_labels[0]);
+	vcal_popup_entries[1].label = _(vcal_popup_labels[1]);
+	vcal_popup_entries[2].label = _(vcal_popup_labels[2]);
+	vcal_popup_entries[3].label = _(vcal_popup_labels[3]);
+	vcal_popup_entries[4].label = _(vcal_popup_labels[4]);
+	vcal_popup_entries[5].label = _(vcal_popup_labels[5]);
+	vcal_popup_radio_entries[0].label = _(vcal_popup_labels[6]);
+	vcal_popup_radio_entries[1].label = _(vcal_popup_labels[7]);
+	vcal_popup_radio_entries[2].label = _(vcal_popup_labels[8]);
 }
 
 static FolderViewPopup vcal_popup =
 {
 	"vCalendar",
 	"<vCalendar>",
-	NULL,
+	vcal_popup_entries,
+	G_N_ELEMENTS(vcal_popup_entries),
+	NULL, 0,
+	vcal_popup_radio_entries, 
+	G_N_ELEMENTS(vcal_popup_radio_entries), 1, set_view_cb,
+	add_menuitems,
 	set_sensitivity
 };
 
@@ -297,9 +303,13 @@ static void vcal_item_opened(FolderItem *item)
 {
 	struct tm tmdate;
 	time_t t = time(NULL);
-
+#ifndef G_OS_WIN32
 	localtime_r(&t, &tmdate);
-
+#else
+	if (t < 0)
+		t = 1;
+	tmdate = *localtime(&t);
+#endif
 	if (!((VCalFolderItem *)(item))->dw 
 	    && ((VCalFolderItem *)(item))->use_cal_view == 1)
 		((VCalFolderItem *)(item))->dw = create_day_win(item, tmdate);		
@@ -615,6 +625,7 @@ add_new:
 					prop = icalcomponent_get_first_property(evt, ICAL_UID_PROPERTY);
 					uid = g_strdup_printf("%s-%d", orig_uid, i);
 					icalproperty_set_uid(prop, uid);
+					/* dont free uid, used after (add_new) */
 					data = icalfeeddata_new(evt, NULL);
 					i++;
 					goto add_new;
@@ -773,6 +784,7 @@ GSList *vcal_get_events_list(FolderItem *item)
 								new_start, new_end, NULL, 
 								event->tzid, event->url, event->method, 
 								event->sequence, event->type);
+					g_free(uid);
 					vcal_manager_copy_attendees(event, nevent);
 					nevent->rec_occurence = TRUE;
 					vcal_manager_save_event(nevent, FALSE);
@@ -809,7 +821,7 @@ static gint vcal_get_num_list(Folder *folder, FolderItem *item,
 	START_TIMING("");
 	g_return_val_if_fail (*list == NULL, 0); /* we expect a NULL list */
 
-	debug_print(" num for %s\n", ((VCalFolderItem *)item)->uri);
+	debug_print(" num for %s\n", ((VCalFolderItem *)item)->uri ? ((VCalFolderItem *)item)->uri:"(null)");
 	
 	*old_uids_valid = FALSE;
 	
@@ -829,6 +841,8 @@ static gint vcal_get_num_list(Folder *folder, FolderItem *item,
 	for (cur = events; cur; cur = cur->next) {
 		VCalEvent *event = (VCalEvent *)cur->data;
 
+		if (!event)
+			continue;
 		g_hash_table_insert(hash_uids, GINT_TO_POINTER(n_msg), g_strdup(event->uid));
 		
 		if (event->rec_occurence) {
@@ -836,7 +850,7 @@ static gint vcal_get_num_list(Folder *folder, FolderItem *item,
 			continue;
 		}
 
-		if (event && event->method != ICAL_METHOD_CANCEL) {
+		if (event->method != ICAL_METHOD_CANCEL) {
 			EventTime days;
 			VCAL_FOLDER_ADD_EVENT(event);
 		}
@@ -905,7 +919,7 @@ static MsgInfo *vcal_get_msginfo(Folder * folder,
 
 		debug_print("  adding %d\n", num);
 	}
-	unlink(file);
+	g_unlink(file);
 	g_free(file);
 
 	debug_print("  got msginfo %p\n", msginfo);
@@ -968,14 +982,13 @@ static gchar *vcal_fetch_msg(Folder * folder, FolderItem * item,
 	gchar *filename = NULL;
 	const gchar *uid = NULL;
 
-	debug_print(" fetch for %s %d\n", ((VCalFolderItem *)item)->uri, num);
+	debug_print(" fetch for %s %d\n", (((VCalFolderItem *)item)->uri ? ((VCalFolderItem *)item)->uri:"(null)"), num);
 	if (((VCalFolderItem *)item)->uri) 
 		return feed_fetch_item(item, num);
 
 	if (!uid) {
 		if (!hash_uids)
 			folder_item_scan_full(item, FALSE);
-
 		uid = g_hash_table_lookup(hash_uids, GINT_TO_POINTER(num));
 	}
 	if (uid && 
@@ -986,12 +999,10 @@ static gchar *vcal_fetch_msg(Folder * folder, FolderItem * item,
 	     !strcmp(uid, EVENT_LATER_ID))) {
 		filename = vcal_manager_dateevent_dump(uid, item);
 	} else if (uid) {
-		VCalEvent *event = vcal_manager_load_event(uid);
-		debug_print("getting %s\n", uid);
-		debug_print("got event %p\n", event);
+		VCalEvent *event = NULL;
+		event = vcal_manager_load_event(uid);
 		if (event)
 			filename = vcal_manager_event_dump(event, FALSE, TRUE, NULL, FALSE);
-		debug_print("dumped to %s\n", filename);
 
 		if (filename) {
 			created_files = g_slist_prepend(created_files, g_strdup(filename));
@@ -1103,7 +1114,7 @@ static gboolean vcal_scan_required(Folder *folder, FolderItem *item)
 
 	if (vitem->uri) {
 		return TRUE;
-	} else if (stat(vcal_manager_get_event_path(), &s) < 0) {
+	} else if (g_stat(vcal_manager_get_event_path(), &s) < 0) {
 		return TRUE;
 	} else if ((s.st_mtime > item->mtime) &&
 		(s.st_mtime - 3600 != item->mtime)) {
@@ -1124,7 +1135,7 @@ static void vcal_set_mtime(Folder *folder, FolderItem *item)
 
 	g_return_if_fail(path != NULL);
 
-	if (stat(path, &s) < 0) {
+	if (g_stat(path, &s) < 0) {
 		FILE_OP_ERROR(path, "stat");
 		g_free(path);
 		return;
@@ -1177,7 +1188,7 @@ static void vcal_remove_event (Folder *folder, MsgInfo *msginfo)
 
 	if (uid) {
 		gchar *file = vcal_manager_get_event_file(uid);
-		unlink(file);
+		g_unlink(file);
 		g_free(file);
 	}
 	
@@ -1228,13 +1239,7 @@ static void vcal_change_flags(Folder *folder, FolderItem *_item, MsgInfo *msginf
 
 void vcal_folder_gtk_init(void)
 {
-	guint i, n_entries;
-
 	vcal_fill_popup_menu_labels();
-	n_entries = sizeof(vcal_popup_entries) /
-		sizeof(vcal_popup_entries[0]);
-	for (i = 0; i < n_entries; i++)
-		vcal_popup.entries = g_slist_append(vcal_popup.entries, &vcal_popup_entries[i]);
 
 	folderview_register_popup(&vcal_popup);
 }
@@ -1248,58 +1253,58 @@ void vcal_folder_gtk_done(void)
 		if (!file)			
 			continue;
 		debug_print("removing %s\n", file);
-		unlink(file);
+		g_unlink(file);
 		g_free(file);
 	}
 	g_slist_free(created_files);
 	folderview_unregister_popup(&vcal_popup);
 }
 
-static gboolean setting_sensitivity = FALSE;
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item)
+{
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "NewMeeting", "FolderViewPopup/NewMeeting", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "ExportCal", "FolderViewPopup/ExportCal", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorVcal1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SubscribeCal", "FolderViewPopup/SubscribeCal", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "UnsubscribeCal", "FolderViewPopup/UnsubscribeCal", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorVcal2", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RenameFolder", "FolderViewPopup/RenameFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorVcal3", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckSubs", "FolderViewPopup/CheckSubs", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorVcal4", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "ListView", "FolderViewPopup/ListView", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "WeekView", "FolderViewPopup/WeekView", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "MonthView", "FolderViewPopup/MonthView", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorVcal5", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+}
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *fitem)
+static gboolean setting_sensitivity = FALSE;
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *fitem)
 {
 	VCalFolderItem *item = (VCalFolderItem *)fitem;
-	GtkWidget *menuitem = NULL;
 
 #define SET_SENS(name, sens) \
-	menu_set_sensitive(factory, name, sens)
+	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
 
 	setting_sensitivity = TRUE;
-	switch(item->use_cal_view) {
-	case 0:
-		menuitem = gtk_item_factory_get_item
-			(factory, _("/List view"));
-		break;
-	case 1:
-		menuitem = gtk_item_factory_get_item
-			(factory, _("/Week view"));
-		break;
-	case 2:
-		menuitem = gtk_item_factory_get_item
-			(factory, _("/Month view"));
-		break;
-	default:
-		menuitem = gtk_item_factory_get_item
-			(factory, _("/List view"));
-		break;
-	}
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), TRUE);
 
-	SET_SENS(_("/New meeting..."), item->uri == NULL);
-	SET_SENS(_("/Export calendar..."), TRUE);
-	SET_SENS(_("/Subscribe to webCal..."), item->uri == NULL);
-	SET_SENS(_("/Unsubscribe..."), item->uri != NULL);
-	SET_SENS(_("/Rename..."), folder_item_parent(fitem) != NULL);
-	SET_SENS(_("/Update subscriptions"), TRUE);
-	SET_SENS(_("/List view"), folder_item_parent(fitem) != NULL);
-	SET_SENS(_("/Week view"), folder_item_parent(fitem) != NULL);
-	SET_SENS(_("/Month view"), folder_item_parent(fitem) != NULL);
+	cm_toggle_menu_set_active_full(ui_manager, "Popup/FolderViewPopup/ListView", (item->use_cal_view == 0));
+	cm_toggle_menu_set_active_full(ui_manager, "Popup/FolderViewPopup/WeekView", (item->use_cal_view == 1));
+	cm_toggle_menu_set_active_full(ui_manager, "Popup/FolderViewPopup/MonthView", (item->use_cal_view == 2));
+	SET_SENS("FolderViewPopup/NewMeeting",   item->uri == NULL);
+	SET_SENS("FolderViewPopup/ExportCal", TRUE);
+	SET_SENS("FolderViewPopup/SubscribeCal", item->uri == NULL);
+	SET_SENS("FolderViewPopup/UnsubscribeCal", item->uri != NULL);
+	SET_SENS("FolderViewPopup/RenameFolder", folder_item_parent(fitem) != NULL);
+	SET_SENS("FolderViewPopup/CheckSubs", TRUE);
+	SET_SENS("FolderViewPopup/ListView", folder_item_parent(fitem) != NULL);
+	SET_SENS("FolderViewPopup/WeekView", folder_item_parent(fitem) != NULL);
+	SET_SENS("FolderViewPopup/MonthView", folder_item_parent(fitem) != NULL);
 	setting_sensitivity = FALSE;
 #undef SET_SENS
 }
 
-static void new_meeting_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void new_meeting_cb(GtkAction *action, gpointer data)
 {
 	debug_print("new_meeting_cb\n");
 	vcal_meeting_create(NULL);
@@ -1437,7 +1442,7 @@ gchar* get_item_event_list_for_date(FolderItem *item, EventTime date)
 	}
 	
 	result = g_strdup_printf(_("\nThese are the events planned %s:\n"),
-			datestr);
+			datestr?datestr:"never");
 	
 	for (cur = g_slist_reverse(strs); cur; cur = cur->next) {
 		int e_len = strlen(result);
@@ -1458,7 +1463,7 @@ gchar* get_item_event_list_for_date(FolderItem *item, EventTime date)
 	return result;
 }
 
-static void export_cal_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void export_cal_cb(GtkAction *action, gpointer data)
 {
 	vcal_meeting_export_calendar(NULL, NULL, NULL, FALSE);
 }
@@ -1511,7 +1516,7 @@ void *url_read_thread(void *data)
 	curl_easy_setopt(curl_ctx, CURLOPT_URL, t_url);
 	curl_easy_setopt(curl_ctx, CURLOPT_WRITEFUNCTION, curl_recv);
 	curl_easy_setopt(curl_ctx, CURLOPT_WRITEDATA, &buffer);
-	curl_easy_setopt(curl_ctx, CURLOPT_TIMEOUT, prefs_common.io_timeout_secs);
+	curl_easy_setopt(curl_ctx, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
 	curl_easy_setopt(curl_ctx, CURLOPT_NOSIGNAL, 1);
 #if LIBCURL_VERSION_NUM >= 0x070a00
 	curl_easy_setopt(curl_ctx, CURLOPT_SSL_VERIFYPEER, 0);
@@ -1529,7 +1534,7 @@ void *url_read_thread(void *data)
 		
 		if(res == CURLE_OPERATION_TIMEOUTED)
 			log_error(LOG_PROTOCOL, _("Timeout (%d seconds) connecting to %s\n"),
-				prefs_common.io_timeout_secs, t_url);
+				prefs_common_get_prefs()->io_timeout_secs, t_url);
 	}
 
 	curl_easy_getinfo(curl_ctx, CURLINFO_RESPONSE_CODE, &response_code);
@@ -1643,6 +1648,7 @@ gboolean vcal_curl_put(gchar *url, FILE *fp, gint filesize, const gchar *user, c
 	}
 	curl_easy_setopt(curl_ctx, CURLOPT_URL, t_url);
 	curl_easy_setopt(curl_ctx, CURLOPT_UPLOAD, 1);
+	curl_easy_setopt(curl_ctx, CURLOPT_READFUNCTION, NULL);
 	curl_easy_setopt(curl_ctx, CURLOPT_READDATA, fp);
 	curl_easy_setopt(curl_ctx, CURLOPT_HTTPHEADER, headers);
 #if LIBCURL_VERSION_NUM >= 0x070a00
@@ -1819,7 +1825,7 @@ static void update_subscription(const gchar *uri, gboolean verbose)
 {
 	FolderItem *item = get_folder_item_for_uri(uri);
 	
-	if (prefs_common.work_offline) {
+	if (prefs_common_get_prefs()->work_offline) {
 		if (!verbose || 
 		!inc_offline_should_override(TRUE,
 		   _("Claws Mail needs network access in order "
@@ -1835,11 +1841,11 @@ static void update_subscription(const gchar *uri, gboolean verbose)
 	vcal_curl_read(uri, verbose, update_subscription_finish);
 }
 
-static void check_subs_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void check_subs_cb(GtkAction *action, gpointer data)
 {
 	Folder *root = folder_find_from_name ("vCalendar", vcal_folder_get_class());
 
-	if (prefs_common.work_offline && 
+	if (prefs_common_get_prefs()->work_offline && 
 	    !inc_offline_should_override(TRUE,
 		     _("Claws Mail needs network access in order "
 		     "to update the subscription.")))
@@ -1848,7 +1854,7 @@ static void check_subs_cb(FolderView *folderview, guint action, GtkWidget *widge
 	folderview_check_new(root);
 }
 
-static void subscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void subscribe_cal_cb(GtkAction *action, gpointer data)
 {
 	gchar *uri = NULL;
 	gchar *tmp = NULL;
@@ -1876,9 +1882,10 @@ static void subscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *wi
 	g_free(uri);
 }
 
-static void unsubscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void unsubscribe_cal_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message;
 	AlertValue avalue;
@@ -1887,7 +1894,7 @@ static void unsubscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->path != NULL);
 	g_return_if_fail(item->folder != NULL);
@@ -1906,7 +1913,7 @@ static void unsubscribe_cal_cb(FolderView *folderview, guint action, GtkWidget *
 	vcal_item_closed(item);
 
 	if (folderview->opened == folderview->selected ||
-	    gtk_ctree_is_ancestor(ctree,
+	    gtk_cmctree_is_ancestor(ctree,
 				  folderview->selected,
 				  folderview->opened)) {
 		summary_clear_all(folderview->summaryview);
@@ -1944,9 +1951,9 @@ gboolean vcal_subscribe_uri(Folder *folder, const gchar *uri)
 	return TRUE;
 }
 
-static void rename_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+static void rename_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *new_folder;
 	gchar *name;
@@ -1988,16 +1995,18 @@ static void rename_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-static void set_view_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void set_view_cb(GtkAction *gaction, GtkRadioAction *current, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	gint action = gtk_radio_action_get_current_value (GTK_RADIO_ACTION (current));
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item = NULL, *oitem = NULL;
 
 	if (!folderview->selected) return;
 	if (setting_sensitivity) return;
 
-	oitem = gtk_ctree_node_get_row_data(ctree, folderview->opened);
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	oitem = gtk_cmctree_node_get_row_data(ctree, folderview->opened);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 
 	if (((VCalFolderItem *)(item))->use_cal_view == action)
 		return;
