@@ -504,7 +504,13 @@ static void get_rfc822_date_from_time_t(gchar *buf, gint len, time_t t)
 	gchar buft1[512];
 	struct tm buft2;
 
+#ifndef G_OS_WIN32
 	lt = localtime_r(&t, &buft2);
+#else
+	if (t < 0)
+		t = 1;
+	lt = localtime(&t);
+#endif
 
 	sscanf(asctime_r(lt, buft1), "%3s %3s %d %d:%d:%d %d\n",
 	       day, mon, &dd, &hh, &mm, &ss, &yyyy);
@@ -544,12 +550,16 @@ static gchar *write_headers_date(const gchar *uid)
 		return NULL;
 	} 
 	
+#ifndef G_OS_WIN32
 	lt = *localtime_r(&t, &buft);
+#else
+	if (t < 0)
+		t = 1;
+	lt = *localtime(&t);
+#endif
 	lt.tm_hour = lt.tm_min = lt.tm_sec = 0;
 	t = mktime(&lt);
-
 	get_rfc822_date_from_time_t(date, sizeof(date), t);
-
 	conv_encode_header(subject, 511, t_subject, strlen("Subject: "), FALSE);
 				
 	return g_strdup_printf("From: -\n"
@@ -567,11 +577,11 @@ static gchar *write_headers_date(const gchar *uid)
 
 gchar *vcal_manager_dateevent_dump(const gchar *uid, FolderItem *item)
 {
-	gchar *sanitized_uid = g_strdup(uid);
+	gchar *sanitized_uid = NULL;
 	gchar *headers = NULL;
 	gchar *lines, *body, *tmpfile;
 	EventTime date;
-	
+	sanitized_uid = g_strdup(uid);
 	subst_for_filename(sanitized_uid);
 	
 	tmpfile = g_strdup_printf("%s%cevt-%d-%s", get_tmp_dir(),
@@ -622,7 +632,7 @@ static gchar *write_headers_ical(PrefsAccount 	*account,
 
 gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcomponent *use_calendar)
 {
-	PrefsAccount *account = cur_account;
+	PrefsAccount *account = account_get_cur_account();
 	gchar *body, *headers, *qpbody;
 	gchar **lines = NULL;
 	gchar *tmpfile = NULL;
@@ -1372,7 +1382,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	folderitem = account_get_special_folder(account, F_QUEUE);
 	if (!folderitem) {
 		g_warning("can't find queue folder for %s\n", account->address);
-		unlink(tmpfile);
+		g_unlink(tmpfile);
 		g_free(tmpfile);
 		return FALSE;
 	}
@@ -1380,14 +1390,14 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	
 	if ((msgnum = folder_item_add_msg(folderitem, tmpfile, NULL, TRUE)) < 0) {
 		g_warning("can't queue the message\n");
-		unlink(tmpfile);
+		g_unlink(tmpfile);
 		g_free(tmpfile);
 		return FALSE;
 	}
 
 	msgpath = folder_item_fetch_msg(folderitem, msgnum);
 	
-	if (!prefs_common.work_offline) {
+	if (!prefs_common_get_prefs()->work_offline) {
 		gchar *err = NULL;
 		gboolean queued_removed = FALSE;
 		gint val = procmsg_send_message_queue(msgpath, &err, folderitem, msgnum, &queued_removed);
@@ -1400,7 +1410,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 			g_free(err);
 		}
 	}
-	unlink(tmpfile);
+	g_unlink(tmpfile);
 	g_free(tmpfile);
 	g_free(msgpath);
 
@@ -1408,7 +1418,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	if (folder)
 		folder_item_scan(folder->inbox);
 
-	vcalviewer_reload();
+	vcalviewer_reload(folder->inbox);
 	return TRUE;
 }
 
@@ -1441,8 +1451,17 @@ EventTime event_to_today(VCalEvent *event, time_t t)
 		evtstart_t = t;
 	}
 	
+#ifndef G_OS_WIN32
 	today = *localtime_r(&today_t, &buft);
 	localtime_r(&evtstart_t, &evtstart);
+#else
+	if (today_t < 0)
+		today_t = 1;
+	if (evtstart_t < 0)
+		evtstart_t = 1;
+	today = *localtime(&today_t);
+	evtstart = *localtime(&evtstart_t);
+#endif
 	
 	if (today.tm_year == evtstart.tm_year) {
 		int days = evtstart.tm_yday - today.tm_yday;
